@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2009 Alexandru Munteanu
+ * Copyright: (C) 2005-2010 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -37,5 +37,5 @@
  *********************************************************/
 
 void put_options_from_preferences();
-void split_it(gpointer data);
+gpointer split_it(gpointer data);
 void sigpipe_handler(gint sig);
