@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright: (C) 2005-2009 Alexandru Munteanu
+ * Copyright: (C) 2005-2010 Alexandru Munteanu
  * Contact: io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
@@ -48,6 +48,7 @@
 #include "player_tab.h"
 #include "utilities.h"
 #include "main_win.h"
+#include "preferences_manager.h"
 
 /* split preferences for choosing directory */
 //directory entry
@@ -100,6 +101,7 @@ extern splt_state *the_state;
 extern gint selected_split_mode;
 extern gint split_file_mode;
 extern GtkWidget *spinner_time;
+extern GtkWidget *spinner_equal_tracks;
 
 //returns the selected language
 //must be free() after
@@ -228,6 +230,7 @@ void save_preferences(GtkWidget *widget, gpointer data)
   //frame mode
   g_key_file_set_boolean(my_key_file, "split", "frame_mode",
       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(frame_mode)));
+
   //adjust mode
   g_key_file_set_boolean(my_key_file, "split", "adjust_mode",
       gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(adjust_mode)));
@@ -261,12 +264,15 @@ void save_preferences(GtkWidget *widget, gpointer data)
   //type of split: split mode
   g_key_file_set_integer(my_key_file, "split", "split_mode",
       selected_split_mode);
-  //type of split: time value
+  //time value
   g_key_file_set_integer(my_key_file, "split", "split_mode_time_value",
       gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spinner_time)));
   //type of split: file mode
   g_key_file_set_integer(my_key_file, "split", "file_mode",
       split_file_mode);
+  //equal time tracks value
+  g_key_file_set_integer(my_key_file, "split", "split_mode_equal_time_tracks",
+      gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spinner_equal_tracks)));
 
   //our data
   gchar *key_data = g_key_file_to_data(my_key_file, NULL, NULL);
@@ -455,7 +461,6 @@ void adjust_event(GtkToggleButton *adjust_mode, gpointer user_data)
 //frame mode event
 void frame_event(GtkToggleButton *frame_mode, gpointer user_data)
 {
-  //if it is toggled
   if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(frame_mode)))
   {
     if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(adjust_mode)))
@@ -470,12 +475,10 @@ void frame_event(GtkToggleButton *frame_mode, gpointer user_data)
 //action for the set default prefs button
 void set_default_prefs_event(GtkWidget *widget, gpointer data)
 {
-  //set frame mode active
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(frame_mode),
-                               TRUE);
+  //set frame mode inactive
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(frame_mode), FALSE);
   //set adjust mode inactive
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(adjust_mode),
-                               FALSE);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(adjust_mode), FALSE);
   //set adjust mode preferences
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(spinner_adjust_threshold),
                             SPLT_DEFAULT_PARAM_THRESHOLD);
@@ -537,7 +540,7 @@ GtkWidget *create_split_options_box()
   gtk_box_pack_start(GTK_BOX(vbox), frame_mode, FALSE, FALSE, 0);
   g_signal_connect(G_OBJECT(frame_mode), "toggled",
       G_CALLBACK(frame_event), NULL);
-  
+
   //auto adjust option
   adjust_mode = gtk_check_button_new_with_mnemonic(_("_Auto-adjust mode (uses"
         " silence detection to auto-adjust splitpoints)"));
