@@ -3,7 +3,7 @@
  * mp3splt-gtk -- utility based on mp3splt,
  *                for mp3/ogg splitting without decoding
  *
- * Copyright (c) 2005-2009 Alexandru Munteanu - io_fx@yahoo.fr
+ * Copyright (c) 2005-2010 Alexandru Munteanu - io_fx@yahoo.fr
  *
  * http://mp3splt.sourceforge.net/
  *
@@ -98,7 +98,5 @@ void handle_detached_event (GtkHandleBox *handlebox,
                             GtkWidget *widget,
                             gpointer data);
 GtkWidget *create_choose_splitpoints_frame(GtkTreeView *tree_view);
-void garray_to_array(GArray *spltpoints, 
-                     glong *hundredth);
 void put_splitpoints_in_the_state(splt_state *state);
 GtkTreeView *create_tree_view();
